import { LitElement, PropertyValues } from "lit";
import { Signal } from "@lit-labs/preact-signals";
import { RenderCanvasSize, RenderWindow, TwoDSlice } from "../../models/rendering";
import { AudioModel } from "../../models/recordings";
import { Hertz, Pixel, Seconds, UnitConverter } from "../../models/unitConverters";
import { WindowFunctionName } from "fft-windowing-ts";
import { SpectrogramOptions } from "../../helpers/audio/models";
export type SpectrogramCanvasScale = "stretch" | "natural" | "original";
export interface IPlayEvent {
    play: boolean;
    keyboardShortcut: boolean;
}
declare const SpectrogramComponent_base: new (...args: any[]) => LitElement;
/**
 * @description
 * A spectrogram component that can be used with the open ecoacoustics components
 *
 * @event Loading
 * @event Finished
 *
 * @slot - A `<source>` element to provide the audio source
 */
export declare class SpectrogramComponent extends SpectrogramComponent_base {
    static styles: import("lit").CSSResult;
    static readonly playEventName = "play";
    static readonly loadingEventName = "loading";
    static readonly loadedEventName = "loaded";
    static readonly optionsChangeEventName = "options-change";
    domRenderWindow?: RenderWindow;
    /** Whether the spectrogram is paused */
    paused: boolean;
    /** The source of the audio file */
    src: string;
    /**
     * The aspect ratio of the spectrogram
     * stretch should scale without aspect ratio
     * natural should scale with the correct aspect ratio to fill the container it
     * is in. One dimension will be constrained by the container, the other by the
     * aspect ratio.
     * original will set the spectrogram to the native resolution of the FFT output.
     * It will not scale the image at all.
     *
     * @values stretch | natural | original
     */
    scaling: SpectrogramCanvasScale;
    /** The size of the fft window */
    windowSize: number;
    /** The window function to use for the spectrogram */
    windowFunction: WindowFunctionName;
    /** The amount of overlap between fft windows */
    windowOverlap: number;
    /** A boolean attribute representing if the spectrogram should be shown in mel-scale */
    melScale: boolean;
    /** A color map to use for the spectrogram */
    colorMap: string;
    /** An offset (seconds) from the start of a larger audio recording */
    offset: number;
    /** An increase in brightness */
    brightness: number;
    /** A scalar multiplier that should be applied to fft values */
    contrast: number;
    slotElements: Array<HTMLElement>;
    private mediaElement;
    private canvas;
    audio: Signal<AudioModel>;
    currentTime: Signal<Seconds>;
    renderCanvasSize: Signal<RenderCanvasSize>;
    renderWindow: Signal<RenderWindow>;
    fftSlice?: TwoDSlice<Pixel, Hertz>;
    unitConverters: Signal<UnitConverter | undefined>;
    private audioHelper;
    private audioContext;
    private highAccuracyTimeBuffer;
    private currentTimeBuffer;
    private doneFirstRender;
    get spectrogramOptions(): SpectrogramOptions;
    set spectrogramOptions(options: SpectrogramOptions);
    get possibleWindowSizes(): ReadonlyArray<number>;
    get possibleWindowOverlaps(): ReadonlyArray<number>;
    get renderedSource(): string;
    hasSource(): boolean;
    disconnectedCallback(): void;
    firstUpdated(): Promise<void>;
    updated(change: PropertyValues<this>): void;
    renderSpectrogram(): void;
    regenerateSpectrogram(): void;
    regenerateSpectrogramOptions(): void;
    resetSettings(): void;
    play(keyboardShortcut?: boolean): void;
    pause(keyboardShortcut?: boolean): void;
    stop(): void;
    private originalFftSize;
    private naturalSize;
    private stretchSize;
    private handleResize;
    private resizeCanvas;
    /**
     * Specifies if the spectrogram is invalidated with the new parameters
     * This method can be used to check if the spectrogram needs to be re-rendered
     */
    private invalidateSpectrogramOptions;
    private invalidateSpectrogramSource;
    /**
     * Returns the amount of time processed by the high accuracy time processor
     * It is important to note that the time does not represent the actual time
     * of the audio element, but is actually a very accurate amount of time that
     * has passed since the worklet node started processing audio
     */
    private highAccuracyElapsedTime;
    private updateCurrentTime;
    private nextRequestId;
    private pollUpdateHighAccuracyTime;
    private setPaused;
    private parseRenderWindow;
    render(): import("lit").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "oe-spectrogram": SpectrogramComponent;
    }
}
export {};
