import { LitElement, PropertyValueMap, PropertyValues, TemplateResult } from "lit";
import { PageFetcher } from "../../services/gridPageFetcher";
import { SubjectWrapper } from "../../models/subject";
import { Signal } from "@lit-labs/preact-signals";
import { decisionColor } from "../../services/colors";
import { GridShape } from "../../helpers/controllers/dynamic-grid-sizes";
import { UrlTransformer } from "../../services/subjectParser";
export type SelectionObserverType = "desktop" | "tablet" | "default";
export type PageOperation = <T = unknown>(subject: SubjectWrapper) => T;
export interface VerificationGridSettings {
    showAxes: Signal<boolean>;
    showMediaControls: Signal<boolean>;
    isFullscreen: Signal<boolean>;
}
export interface VerificationGridInjector {
    colorService: typeof decisionColor;
}
export interface MousePosition {
    x: number;
    y: number;
}
declare const VerificationGridComponent_base: new (...args: any[]) => LitElement;
/**
 * @description
 * A verification grid component that can be used to verify audio events
 *
 * @example
 * ```html
 * <oe-verification-grid gridSize="10">
 *   <template>
 *     <oe-info-card></oe-info-card>
 *   </template>
 *
 *   <oe-verification verified="true"></oe-verification>
 *   <oe-verification verified="false"></oe-verification>
 *
 *   <oe-data-source slot="data-source" for="verification-grid" src="/public/grid-items.json" local>
 *   </oe-data-source>
 * </oe-verification-grid>
 * ```
 *
 * @dependency oe-verification-grid-tile
 *
 * @slot - A template element that will be used to create each grid tile
 * @slot - Decision elements that will be used to create the decision buttons
 * @slot data-source - An `oe-data-source` element that provides the data
 *
 * @event { SubjectModel[] } decision-made - Emits information about the decision that was made
 * @event loaded - Emits when all the spectrograms have been loaded
 */
export declare class VerificationGridComponent extends VerificationGridComponent_base {
    static styles: import("lit").CSSResult;
    static readonly decisionMadeEventName: "decision-made";
    private static readonly loadedEventName;
    private static readonly autoPageTimeout;
    settings: VerificationGridSettings;
    injector: VerificationGridInjector;
    /** The number of items to display in a single grid */
    targetGridSize: number;
    /**
     * The selection behavior of the verification grid
     * @values "desktop" | "tablet" | "default"
     * @default "default"
     */
    selectionBehavior: SelectionObserverType;
    /** A callback function that returns a page of recordings */
    getPage?: PageFetcher;
    /**
     * A callback function that will be applied to all subject urls
     *
     * @default
     * an identity function that returns the url unchanged
     */
    urlTransformer: UrlTransformer;
    /** selector for oe-verification elements */
    private verificationDecisionElements;
    /** selector for oe-classification elements */
    private classificationDecisionElements;
    /** A selector for all oe-verification and oe-classification elements */
    private decisionElements;
    private gridItemTemplate?;
    private gridTiles;
    private bootstrapDialog;
    private gridContainer;
    private decisionsContainer;
    private skipButton;
    private highlightBox;
    columns: number;
    rows: number;
    private currentSubSelection;
    get gridShape(): GridShape;
    /**
     * The index of the first item from the `subjects` array in the currently
     * displayed verification grid page
     */
    get viewHead(): number;
    set viewHead(value: number);
    /**
     * The index from the `subjects` array indicating up to which point
     * decisions have been made
     * It is updated as each page is completed
     */
    get decisionHead(): number;
    private set decisionHead(value);
    /** A count of the number of tiles shown in the grid */
    get populatedTileCount(): number;
    /** A count of the number of tiles currently visible on the screen */
    get effectivePageSize(): number;
    private get currentPageIndices();
    private keydownHandler;
    private keyupHandler;
    private blurHandler;
    private selectionHandler;
    private decisionHandler;
    subjects: SubjectWrapper[];
    private decisionHeadIndex;
    private viewHeadIndex;
    private requiredClassificationTags;
    private requiredDecisions;
    private hiddenTiles;
    private decisionsDisabled;
    private showingSelectionShortcuts;
    private selectionHead;
    private anyOverlap;
    private gridController?;
    private paginationFetcher?;
    private highlight;
    connectedCallback(): void;
    disconnectedCallback(): void;
    isViewingHistory(): boolean;
    resetSpectrogramSettings(): void;
    isBootstrapDialogOpen(): boolean;
    pushToSubjects(value: SubjectWrapper[]): void;
    firstUpdated(): void;
    protected willUpdate(change: PropertyValues<this>): void;
    protected updated(change: PropertyValueMap<this>): Promise<void>;
    private defaultGridSize;
    private handleTileInvalidation;
    /**
     * handles the data source of the verification grid changing
     * this will reset the verification task and re-fetch the first page of
     * subjects from the new data source
     */
    private handleGridSourceInvalidation;
    /**
     * handles the currently rendered page of subjects changing
     * e.g. the number of tiles being rendered, or the source of a singular tile
     *      changing
     * causing the current page to be re-rendered from the viewHead position
     */
    private handlePageInvalidation;
    private resetBufferHeads;
    private updateRequiredDecisions;
    private updateRequiredClassificationTags;
    private updateInjector;
    private updateDecisionElements;
    private currentPage;
    private handleKeyDown;
    private handleKeyUp;
    /**
     * Catches a verification grid tiles play event, and conditionally cancels it
     * based on the current selection state.
     *
     * Reminder: The play shortcut is listened for by each media-controls, so this
     * handler runs grid size times when the play shortcut is pressed.
     */
    private handleTilePlay;
    private handleWindowBlur;
    private handleHelpRequest;
    private handleBootstrapDialogOpen;
    private handleBootstrapDialogClose;
    private handleSlotChange;
    private handleTileOverlap;
    private tileSelectionShortcutsShown;
    private showSelectionShortcuts;
    private hideSelectionShortcuts;
    private handleSelection;
    private toggleTileSelection;
    private addSubSelectionRange;
    private subSelectAll;
    private removeSubSelection;
    private canSubSelect;
    private isMobileDevice;
    private updateSubSelection;
    private renderHighlightBox;
    private updateHighlightObservedElements;
    private resizeHighlightBox;
    private calculateHighlightIntersection;
    private hideHighlightBox;
    private handlePreviousPageClick;
    private handleNextPageClick;
    private pageForward;
    private pageBackward;
    /** Changes the viewHead to the current page of undecided results */
    private resumeVerification;
    private nextPage;
    private canNavigatePrevious;
    private canNavigateNext;
    private handleDecision;
    private shouldAutoPage;
    private hasOutstandingVerification;
    private hasOutstandingClassification;
    private setDecisionDisabled;
    private renderVirtualPage;
    private hideGridItems;
    private showAllGridItems;
    private hasDecisionElements;
    private areSpectrogramsLoaded;
    private handleSpectrogramLoaded;
    private hasClassificationTask;
    private hasVerificationTask;
    private mixedTaskPromptTemplate;
    private classificationTaskPromptTemplate;
    private verificationTaskPromptTemplate;
    private decisionPromptTemplate;
    private noItemsTemplate;
    private noDecisionsTemplate;
    private skipDecisionTemplate;
    render(): TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "oe-verification-grid": VerificationGridComponent;
    }
}
export {};
