import { Classification } from "./decisions/classification";
import { Decision, DecisionOptions } from "./decisions/decision";
import { Verification } from "./decisions/verification";
import { Tag } from "./tag";
import { EnumValue } from "../helpers/types/advancedTypes";
export declare enum AudioCachedState {
    COLD = 0,
    REQUESTED = 1,
    SUCCESS = 2,
    FAILED = 3
}
/** Original unprocessed data from the data source */
export type Subject = Record<PropertyKey, unknown>;
declare const columnNamespace: "oe_";
declare const tagColumnName: "oe_tag";
declare const confirmedColumnName: "oe_confirmed";
type ClassificationColumn = `${typeof columnNamespace}${string}`;
export interface DownloadableResult extends Subject {
    [tagColumnName]: string;
    [confirmedColumnName]: EnumValue<DecisionOptions>;
    [key: ClassificationColumn]: EnumValue<DecisionOptions>;
}
/**
 * @constructor
 * @param {Subject} subject
 * The original data provided by the data source
 *
 * @param {String} url
 * The url that has been extracted from the original data source
 *
 * @param {Tag} tag
 * The tag that has been extracted from the original data source
 */
export declare class SubjectWrapper {
    constructor(subject: Subject, url: string, tag: Tag);
    /**
     * @description
     * aka: context
     * this is the native data model used by the host application
     * or this could be the csv row
     *
     * !the subject object reference must remain the same for the lifetime of
     * !the application, otherwise downloading results will result in unexpected
     * !or incorrect output
     */
    subject: Readonly<Subject>;
    /** If the audio has been pre-fetched using a GET request */
    clientCached: AudioCachedState;
    /** If the audio has been warmed/split on the server using a HEAD request */
    serverCached: AudioCachedState;
    verification?: Verification;
    classifications: Map<string, Classification>;
    url: string;
    tag: Tag;
    /**
     * Adds a decision to the subject and removes any decisions that have been
     * made against the same tag.
     * Decisions that are made about the same tag are removed so that it is not
     * possible to have both a positive and negative decision about a tag
     */
    addDecision(decision: Decision): void;
    /** Removes a decision from the subject */
    removeDecision(decision: Decision): void;
    /**
     * @description
     * Compares the subjects decisions to an array of required tags and
     * applies a skip decision to any required tags that do not have a decision
     * made about them
     *
     * @param {Boolean} requiresVerification
     * Looks at the subject model and applies a skip decision to the
     * verification task if none is applied
     *
     * @param {Array} requiredClassifications
     * Classifications that will be * applied as a skip decision if not present
     * on the subject
     */
    skipUndecided(requiresVerification: boolean, requiredClassifications: Tag[]): void;
    /** Checks if the current subject has a decision */
    hasDecision(queryingDecision: Decision): boolean;
    toDownloadable(): Partial<DownloadableResult>;
    private addVerification;
    private addClassification;
    private removeVerification;
    private removeClassification;
}
export {};
